@@ -1,6 +1,9 @@
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.importlib import import_module
-from django.db import connection
+try:
+    from importlib import import_module
+except ImportError:
+    from django.utils.importlib import import_module
+from django.db import connection, transaction
 
 from haystack.utils import get_identifier
 
@@ -23,21 +26,30 @@ def get_update_task(task_path=None):
     return Task()
 
 
-def enqueue_task(action, instance):
+def enqueue_task(action, instance, **kwargs):
     """
     Common utility for enqueing a task for the given action and
     model instance.
     """
     identifier = get_identifier(instance)
-    kwargs = {}
+    options = {}
     if settings.CELERY_HAYSTACK_QUEUE:
-        kwargs['queue'] = settings.CELERY_HAYSTACK_QUEUE
+        options['queue'] = settings.CELERY_HAYSTACK_QUEUE
     if settings.CELERY_HAYSTACK_COUNTDOWN:
-        kwargs['countdown'] = settings.CELERY_HAYSTACK_COUNTDOWN
+        options['countdown'] = settings.CELERY_HAYSTACK_COUNTDOWN
+
     task = get_update_task()
-    if hasattr(connection, 'on_commit'):
+    task_func = lambda: task.apply_async((action, identifier), kwargs, **options)
+
+    if hasattr(transaction, 'on_commit'):
+        # Django 1.9 on_commit hook
+        transaction.on_commit(
+            task_func
+        )
+    elif hasattr(connection, 'on_commit'):
+        # Django-transaction-hooks
         connection.on_commit(
-            lambda: task.apply_async((action, identifier), {}, **kwargs)
+            task_func
         )
     else:
-        task.apply_async((action, identifier), {}, **kwargs)
+        task_func()
